@@ -13,6 +13,31 @@
         <source>Restore theme files</source>
         <translation>Tiedostojen palautus</translation>
     </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Save as new theme</source>
+        <translation>Tallenna uutena teemana</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>You must give name for the theme.</source>
+        <translation>Sinun on annettava teemalle nimi.</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Folder </source>
+        <translation>Kansio </translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source> already exists!</source>
+        <translation> on jo olemassa!</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Saving new theme...</source>
+        <translation>Tallenetaan uutta teemaa...</translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Menu bar opacity</source>
@@ -480,4 +505,17 @@
         <translation>Nykyisen teeman alkuperäiset värit</translation>
     </message>
 </context>
+<context>
+    <name>savenewtheme</name>
+    <message>
+        <location filename="savenewtheme.ui" line="0"/>
+        <source>Save theme as...</source>
+        <translation>Tallenna teema nimellä...</translation>
+    </message>
+    <message>
+        <location filename="savenewtheme.ui" line="0"/>
+        <source>Save</source>
+        <translation>Tallenna</translation>
+    </message>
+</context>
 </TS>
