@@ -21,27 +21,27 @@
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>You must give name for the theme.</source>
-        <translation type="unfinished"></translation>
+        <translation>Vous devez donner un nom au thème.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Folder </source>
-        <translation type="unfinished"></translation>
+        <translation>Dossier </translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source> already exists!</source>
-        <translation type="unfinished"></translation>
+        <translation> existe dèja!</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Saving new theme...</source>
-        <translation type="unfinished"></translation>
+        <translation>Sauvegarde du nouveau thème...</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Save as new theme</source>
-        <translation type="unfinished"></translation>
+        <translation>Sauvegarder comme un  nouveau thème</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
@@ -514,12 +514,12 @@ déverrouillage</translation>
     <message>
         <location filename="savenewtheme.ui" line="0"/>
         <source>Save theme as...</source>
-        <translation type="unfinished"></translation>
+        <translation>Sauvegarder le thème sous...</translation>
     </message>
     <message>
         <location filename="savenewtheme.ui" line="0"/>
         <source>Save</source>
-        <translation type="unfinished"></translation>
+        <translation>Enregistrer</translation>
     </message>
 </context>
 </TS>
